@@ -1,10 +1,12 @@
 import ctypes as ct
+from typing import Mapping
+
 from coreir.global_value import GlobalValue, COREGlobalValue
 from coreir.type import CoreIRType, Values
 from coreir.lib import libcoreir_c
 from coreir.wireable import Instance, Interface, Wireable
 from coreir.type import COREValue_p, COREValueType_p, Value, Record, ValueType
-from coreir.util import decode_cptr_and_free
+from coreir.util import decode_cptr_and_free, raise_mapping
 import coreir.wireable
 import json
 
@@ -66,7 +68,9 @@ class ModuleDef(CoreIRType):
             curr = libcoreir_c.COREModuleDefInstancesIterNext(self.ptr, curr)
         return result
 
-    def get_instance(self,inst_name):
+    def get_instance(self, inst_name):
+        if inst_name == "self":
+            return self.interface
         for inst in self.instances:
             if inst.name==inst_name:
                 return inst
@@ -185,6 +189,24 @@ class Module(GlobalValue):
         mjson = json.loads(pstr)
         return mjson
 
+    def link_module(self, key: str, target: 'Module') -> bool:
+        return libcoreir_c.COREModuleLinkModule(
+            str.encode(key), self.ptr, target.ptr)
+
+    def get_linked_modules(self) -> Mapping[str, 'Module']:
+        return raise_mapping(
+            self, COREModule_p, Module, libcoreir_c.COREModuleGetLinkedModules)
+
+    def link_default_module(self, target: 'Module') -> bool:
+        return libcoreir_c.COREModuleLinkDefaultModule(self.ptr, target.ptr)
+
+    def has_default_linked_module(self) -> bool:
+        return libcoreir_c.COREModuleHasDefaultLinkedModule(self.ptr)
+
+    def get_default_linked_module(self) -> bool:
+        ptr = libcoreir_c.COREModuleGetDefaultLinkedModule(self.ptr)
+        return Module(ptr, self.context)
+
 
 class COREDirectedInstance(ct.Structure):
     pass
